import { Outlet } from 'react-router-dom';
import Header from './Header';
import Footer from './Footer';
import { useAuth } from '../../contexts/AuthContext'; // Import useAuth

console.log('Layout.jsx: Rendering Layout component'); // Add logging

function Layout() {
  const { isInitialized } = useAuth(); // Use isInitialized from auth context

  // Optionally render a loading state if auth is not initialized
  if (!isInitialized) {
     console.log('Layout.jsx: Auth not initialized, rendering loading state.'); // Add logging
     return (
        <div className="min-h-screen flex items-center justify-center bg-campfire-dark">
           <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-campfire-amber"></div>
        </div>
     );
  }

  console.log('Layout.jsx: Auth initialized, rendering Header, Outlet, and Footer.'); // Add logging
  return (
    <div className="flex flex-col min-h-screen bg-campfire-dark text-campfire-light">
      <Header />
      {/* Removed container-custom and mx-auto to allow content to stretch */}
      <main className="flex-grow px-4 py-8">
        <Outlet /> {/* Renders the matched route's component */}
      </main>
      <Footer />
    </div>
  );
}

export default Layout;
