import React, { createContext, useContext, useCallback, useRef } from 'react';
import ClickSpark from '../components/reactbits/Animations/ClickSpark/ClickSpark';

const ClickSparkContext = createContext(null);

export const useClickSpark = () => {
  const context = useContext(ClickSparkContext);
  if (!context) {
    throw new Error('useClickSpark must be used within a ClickSparkProvider');
  }
  return context;
};

export const ClickSparkProvider = ({ children }) => {
  const clickSparkRef = useRef(null);

  const addSpark = useCallback((x, y) => {
    console.log('[ClickSpark] Добавление искры:', x, y);
    if (clickSparkRef.current) {
      clickSparkRef.current.addSpark(x, y);
    }
  }, []);

  return (
    <ClickSparkContext.Provider value={{ addSpark }}>
      <ClickSpark
        ref={clickSparkRef}
        sparkColor="#FFA500"
        sparkSize={10}
        sparkRadius={15}
        sparkCount={8}
        duration={400}
        easing="cubic-bezier(0.4, 0, 0.2, 1)"
        extraScale={1.0}
      >
        {children}
      </ClickSpark>
    </ClickSparkContext.Provider>
  );
}; 